From 4f40770fc60c0779acab9fc7f35f60b67b0340c7 Mon Sep 17 00:00:00 2001
From: frohlich <frohlich>
Date: Thu, 14 Dec 2006 05:24:16 +0000
Subject: [PATCH] Modified Files: 	simgear/math/SGVec3.hxx: fix spelling

---
 simgear/math/SGVec3.hxx | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/simgear/math/SGVec3.hxx b/simgear/math/SGVec3.hxx
index d9d998df..7d4eec13 100644
--- a/simgear/math/SGVec3.hxx
+++ b/simgear/math/SGVec3.hxx
@@ -364,11 +364,11 @@ cross(const SGVec3<T>& v1, const SGVec3<T>& v2)
                    v1(0)*v2(1) - v1(1)*v2(0));
 }
 
 /// return any vector perpandicular to v
 template<typename T>
 inline
 SGVec3<T>
-perpandicular(const SGVec3<T>& v)
+perpendicular(const SGVec3<T>& v)
 {
   if (fabs(v.x()) < fabs(v.y()) && fabs(v.x()) < fabs(v.z()))
     return cross(SGVec3f(1, 0, 0), v);
@@ -364,11 +364,11 @@ cross(const SGVec3<T>& v1, const SGVec3<T>& v2)
 }
 
-/// return any vector perpandicular to v
+/// return any vector perpendicular to v
 template<typename T>
 inline
-- 
2.39.5